@@ -98,7 +98,7 @@ class HttpOTA:
             if status['updated']:
                 if status['need_reset']:
                     self.logger.warning("Resetting")
-                    machine.soft_reset()
+                    machine.reset()
                 else:
                     self.logger.debug("Nothing was updated")
             else:
